package com.ruoyi.inventory.service;

import java.util.List;
import com.ruoyi.inventory.domain.HealthcareInventoryDrugout;

/**
 * 药品出库记录Service接口
 * 
 * @author 蒋松霖
 * @date 2024-10-07
 */
public interface IHealthcareInventoryDrugoutService 
{
    /**
     * 查询药品出库记录
     * 
     * @param id 药品出库记录主键
     * @return 药品出库记录
     */
    public HealthcareInventoryDrugout selectHealthcareInventoryDrugoutById(Long id);

    /**
     * 查询药品出库记录列表
     * 
     * @param healthcareInventoryDrugout 药品出库记录
     * @return 药品出库记录集合
     */
    public List<HealthcareInventoryDrugout> selectHealthcareInventoryDrugoutList(HealthcareInventoryDrugout healthcareInventoryDrugout);

    /**
     * 新增药品出库记录
     * 
     * @param healthcareInventoryDrugout 药品出库记录
     * @return 结果
     */
    public int insertHealthcareInventoryDrugout(HealthcareInventoryDrugout healthcareInventoryDrugout);

    /**
     * 修改药品出库记录
     * 
     * @param healthcareInventoryDrugout 药品出库记录
     * @return 结果
     */
    public int updateHealthcareInventoryDrugout(HealthcareInventoryDrugout healthcareInventoryDrugout);

    /**
     * 批量删除药品出库记录
     * 
     * @param ids 需要删除的药品出库记录主键集合
     * @return 结果
     */
    public int deleteHealthcareInventoryDrugoutByIds(Long[] ids);

    /**
     * 删除药品出库记录信息
     * 
     * @param id 药品出库记录主键
     * @return 结果
     */
    public int deleteHealthcareInventoryDrugoutById(Long id);

    int saveHealthcareInventoryDrugout(HealthcareInventoryDrugout healthcareInventoryDrugout);
}
