package com.ruoyi.inventory.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.inventory.domain.HealthcareInventoryDrugout;
import com.ruoyi.inventory.service.IHealthcareInventoryDrugoutService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 药品出库记录Controller
 * 
 * @author 蒋松霖
 * @date 2024-10-07
 */
@RestController
@RequestMapping("/pasd-healthcare/drugout")
public class HealthcareInventoryDrugoutController extends BaseController {
    @Autowired
    private IHealthcareInventoryDrugoutService healthcareInventoryDrugoutService;

    /**
     * 查询药品出库记录列表
     */
    @PreAuthorize("@ss.hasPermi('pasd-healthcare:drugout:list')")
    @GetMapping("/list")
    public TableDataInfo list(HealthcareInventoryDrugout healthcareInventoryDrugout) {
        startPage();
        List<HealthcareInventoryDrugout> list = healthcareInventoryDrugoutService
                .selectHealthcareInventoryDrugoutList(healthcareInventoryDrugout);
        return getDataTable(list);
    }

    /**
     * 导出药品出库记录列表
     */
    @PreAuthorize("@ss.hasPermi('pasd-healthcare:drugout:export')")
    @Log(title = "药品出库记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, HealthcareInventoryDrugout healthcareInventoryDrugout) {
        List<HealthcareInventoryDrugout> list = healthcareInventoryDrugoutService
                .selectHealthcareInventoryDrugoutList(healthcareInventoryDrugout);
        ExcelUtil<HealthcareInventoryDrugout> util = new ExcelUtil<HealthcareInventoryDrugout>(
                HealthcareInventoryDrugout.class);
        util.exportExcel(response, list, "药品出库记录数据");
    }

    /**
     * 获取药品出库记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('pasd-healthcare:drugout:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(healthcareInventoryDrugoutService.selectHealthcareInventoryDrugoutById(id));
    }

    /**
     * 新增药品出库记录
     */
    @PreAuthorize("@ss.hasPermi('pasd-healthcare:drugout:add')")
    @Log(title = "药品出库记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody HealthcareInventoryDrugout healthcareInventoryDrugout) {
        return toAjax(healthcareInventoryDrugoutService.insertHealthcareInventoryDrugout(healthcareInventoryDrugout));
    }

    /**
     * 修改药品出库记录
     */
    @PreAuthorize("@ss.hasPermi('pasd-healthcare:drugout:edit')")
    @Log(title = "药品出库记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody HealthcareInventoryDrugout healthcareInventoryDrugout) {
        return toAjax(healthcareInventoryDrugoutService.updateHealthcareInventoryDrugout(healthcareInventoryDrugout));
    }

    /**
     * 删除药品出库记录
     */
    @PreAuthorize("@ss.hasPermi('pasd-healthcare:drugout:remove')")
    @Log(title = "药品出库记录", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(healthcareInventoryDrugoutService.deleteHealthcareInventoryDrugoutByIds(ids));
    }

    /**
     * 保存操作
     */
    @Log(title = "保存药品入库记录", businessType = BusinessType.INSERT)
    @PreAuthorize("@ss.hasPermi('pasd-healthcare:drugout:add')")
    @PostMapping("/save")
    public AjaxResult save(@RequestBody HealthcareInventoryDrugout healthcareInventoryDrugout) {
        return toAjax(healthcareInventoryDrugoutService.saveHealthcareInventoryDrugout(healthcareInventoryDrugout));
    }
}
